==> ikapi-0.0.6.tgz: package/src/API/IKResponse.js <==
import IKGlobals from './../IKGlobals';
//
import AWS from "aws-sdk";
import Utils from "./IKUtils";
//
export function IKMissingParamResponse(paramName) {
  console.warning(`Invalid request - Path parameter ${paramName} is missing.`);
  return (new IKResponse(400, {err: `Invalid request. Path parameter ${paramName} is missing.`, errCode: IKGlobals.ErrorCode_MissingParam}));
}
export function IKBadRequestResponse(msg, errCode) {
  console.warning(`Bad request - ${msg}`);
  return (new IKResponse(400, {err: msg, ...(errCode ? {errCode: errCode} : {})}));
}
export function IKUnauthorizedResponse(msg, errCode) {
  console.warning(`Denying request - ${msg}`);
  return (new IKResponse(401, {err: msg, ...(errCode ? {errCode: errCode} : {})}));
}
export function IKSuccessResponse(msg) { return (new IKResponse(200, (msg ? msg : {}))); }
//
export default class IKResponse {
  constructor(statusCode, body) {
    this._statusCode = statusCode;
    this._body = body;
  }
  getCode() { return this._statusCode; }
  appendIntoBody(key, value) { this._body[key] = value; }
  build(context, requestID) {
    //append default fields
    if (requestID) this.appendIntoBody('transactionID', requestID); //append transaction ID
    //build response
    let b = {
      statusCode: this._statusCode,
      body: JSON.stringify(this._body),
      headers: {
        "Access-Control-Allow-Origin": "*",
        "Access-Control-Allow-Credentials": true
      }
    };
    //log response and respond to context
    console.debug(b)
    context.succeed(b);
  }
}

==> ikapi-0.3.9.tgz: package/src/API/IKResponse.js <==
import IKGlobals from './../IKGlobals';
//
import AWS from "aws-sdk";
import Utils from "./IKUtils";
//
export function IKMissingParamResponse(paramName) {
  console.warning(`Invalid request - Path parameter ${paramName} is missing.`);
  return (new IKResponse(400, {err: `Invalid request. Path parameter ${paramName} is missing.`, errCode: IKGlobals.ErrorCode_MissingParam}));
}
export function IKBadRequestResponse(msg, errCode) {
  console.warning(`Bad request - ${msg}`);
  return (new IKResponse(400, {err: msg, ...(errCode ? {errCode: errCode} : {})}));
}
export function IKUnauthorizedResponse(msg, errCode) {
  console.warning(`Denying request - ${msg}`);
  return (new IKResponse(401, {err: msg, ...(errCode ? {errCode: errCode} : {})}));
}
export function IKSuccessResponse(msg) { return (new IKResponse(200, (msg ? msg : {}))); }
//
export default class IKResponse {
  constructor(statusCode, body) {
    this._statusCode = statusCode;
    this._body = body;
  }
  getCode() { return this._statusCode; }
  appendIntoBody(key, value) { this._body[key] = value; }
  build(context, requestID) {
    //append default fields
    if (requestID) this.appendIntoBody('transactionID', requestID); //append transaction ID
    //build response
    let b = {
      statusCode: this._statusCode,
      body: JSON.stringify(this._body),
      headers: {
        "Access-Control-Allow-Origin": "*",
        "Access-Control-Allow-Credentials": true,
        "Content-Type": "application/json"
      }
    };
    //log response and respond to context
    console.debug(b)
    context.succeed(b);
  }
}
